@@ -148,11 +148,15 @@ class FastPunct():
         
         home = os.path.expanduser("~")
         lang_path = os.path.join(home, '.fastPunct_' + lang_code)
-        weights_path = os.path.join(lang_path, 'checkpoint.h5')
-        params_path = os.path.join(lang_path, 'params.pkl')
-
-        if not os.path.exists(lang_path):
-            os.mkdir(lang_path)
+        if weights_path is None:
+            weights_path = os.path.join(lang_path, 'checkpoint.h5')
+        if params_path is None:
+            params_path = os.path.join(lang_path, 'params.pkl')
+        
+        #if either of the paths are not mentioned, then, make lang directory from home
+        if (params_path is None) or (weights_path is None):
+            if not os.path.exists(lang_path):
+                os.mkdir(lang_path)
 
         if not os.path.exists(weights_path):
             print('Downloading checkpoint', model_links[lang_code]['checkpoint'], 'to', weights_path)
@@ -180,4 +184,4 @@ class FastPunct():
     
 if __name__ == "__main__":
     fastpunct = FastPunct()
-    print(fastpunct.punct(["My name is sid and i want to become a data scientist.", "in theory everyone knows what a comma is", "hey how are you doing", "my name is sheela i am in love with hrithik"]))
+    print(fastpunct.punct(["oh i thought you were here", "in theory everyone knows what a comma is", "hey how are you doing", "my name is sheela i am in love with hrithik"]))
